pub struct AppStateData {
pub db: Arc<dyn DbProvider>,
pub signing_key: Key,
pub settings: Arc<Settings>,
pub crate_storage: Arc<KellnrCrateStorage>,
pub cratesio_storage: Arc<CratesIoCrateStorage>,
pub cratesio_prefetch_sender: Sender<CratesioPrefetchMsg>,
pub token_cache: Arc<TokenCacheManager>,
pub toolchain_storage: Option<Arc<ToolchainStorage>>,
pub download_counter: Arc<DownloadCounter>,
pub proxy_client: Client,
}Fields
db: Arc<dyn DbProvider>signing_key: Keysettings: Arc<Settings>crate_storage: Arc<KellnrCrateStorage>cratesio_storage: Arc<CratesIoCrateStorage>cratesio_prefetch_sender: Sender<CratesioPrefetchMsg>token_cache: Arc<TokenCacheManager>toolchain_storage: Option<Arc<ToolchainStorage>>download_counter: Arc<DownloadCounter>proxy_client: ClientTrait Implementations
Sourceimpl Clone for AppStateData
impl Clone for AppStateData
Sourcefn clone(&self) -> AppStateData
fn clone(&self) -> AppStateData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl FromRef<AppStateData> for Arc<CratesIoCrateStorage>
impl FromRef<AppStateData> for Arc<CratesIoCrateStorage>
Sourcefn from_ref(state: &AppStateData) -> Self
fn from_ref(state: &AppStateData) -> Self
Converts to this type from a reference to the input type.
Sourceimpl FromRef<AppStateData> for Arc<DownloadCounter>
impl FromRef<AppStateData> for Arc<DownloadCounter>
Sourcefn from_ref(state: &AppStateData) -> Self
fn from_ref(state: &AppStateData) -> Self
Converts to this type from a reference to the input type.
Sourceimpl FromRef<AppStateData> for Arc<KellnrCrateStorage>
impl FromRef<AppStateData> for Arc<KellnrCrateStorage>
Sourcefn from_ref(state: &AppStateData) -> Self
fn from_ref(state: &AppStateData) -> Self
Converts to this type from a reference to the input type.
Sourceimpl FromRef<AppStateData> for Arc<Settings>
impl FromRef<AppStateData> for Arc<Settings>
Sourcefn from_ref(state: &AppStateData) -> Self
fn from_ref(state: &AppStateData) -> Self
Converts to this type from a reference to the input type.
Sourceimpl FromRef<AppStateData> for Arc<TokenCacheManager>
impl FromRef<AppStateData> for Arc<TokenCacheManager>
Sourcefn from_ref(state: &AppStateData) -> Self
fn from_ref(state: &AppStateData) -> Self
Converts to this type from a reference to the input type.
Sourceimpl FromRef<AppStateData> for Arc<dyn DbProvider>
impl FromRef<AppStateData> for Arc<dyn DbProvider>
Sourcefn from_ref(state: &AppStateData) -> Self
fn from_ref(state: &AppStateData) -> Self
Converts to this type from a reference to the input type.
Sourceimpl FromRef<AppStateData> for Client
impl FromRef<AppStateData> for Client
Sourcefn from_ref(state: &AppStateData) -> Self
fn from_ref(state: &AppStateData) -> Self
Converts to this type from a reference to the input type.
Sourceimpl FromRef<AppStateData> for Key
impl FromRef<AppStateData> for Key
Sourcefn from_ref(state: &AppStateData) -> Self
fn from_ref(state: &AppStateData) -> Self
Converts to this type from a reference to the input type.
Sourceimpl FromRef<AppStateData> for Option<Arc<ToolchainStorage>>
impl FromRef<AppStateData> for Option<Arc<ToolchainStorage>>
Sourcefn from_ref(state: &AppStateData) -> Self
fn from_ref(state: &AppStateData) -> Self
Converts to this type from a reference to the input type.
Sourceimpl FromRef<AppStateData> for Sender<CratesioPrefetchMsg>
impl FromRef<AppStateData> for Sender<CratesioPrefetchMsg>
Sourcefn from_ref(state: &AppStateData) -> Self
fn from_ref(state: &AppStateData) -> Self
Converts to this type from a reference to the input type.